-- 
-- Template para criacao de um grafico XY simples.
--
-- Pode ainda habilitar ou no legendas a esquerda ou abaixo do grafico.
-- A esquerda podemos contar com legenda de curvas
--
-- Ttulo e sub-ttulo do grfico podem ser escondidos de acordo com a 
-- necessidade.
--
-- Dados Recebidos:
--
-- Config.graphTitle    = Titulo do grafico
-- Config.graphSubtitle = Subtitulo do grafico
-- Config.templateName  = Nome do template selecionado
-- Config.templateIndex = Indice em TemplatesList contendo a descrica do 
--                        template
--
-- Config.areas = Tabela contendo dados relacionados com as areas de
--                desenho do template.  Deve possuir tantas entradas 
--                quanto o numero de PlotAreas do grfico, neste caso
--                especfico, apenas uma.  O nome de cada uma destas 
--                entradas deve ser correspondente ao nome cadastrado
--                no arquivo de configurao dos templates, neste caso, 
--                GraphArea
--
-- Config.areas.GraphArea = Conjunto de dados relacionados a rea de 
--                          desenho. Campos: 
--     title     = Nome extendido da rea
--     xaxeIndex = Indice correspondente ao eixo X na tabela AxeTypeList
--     xaxeTitle = Titulo do eixo X
--     xaxeDir   = Direcao do eixo X (HORIZONTAL ou VERTICAL)
--
--     y1axeIndex  = Indice correspondente ao eixo Y na tabela AxeTypeList.
--     y1axeTitle  = Titulo do eixo Y 
--     y1axeSeries = Tabela contendo os indices em SeriesList das curvas
--                   adicionadas a este eixo. 
--     
-- Para que o esquema padro de identificao de objetos funcione corretamente,
--  necessrio que reas e eixos sejam criados na mesma ordem em que esto
-- definidos no template bsico
--

assert(CurrentGraphic)
assert(Config and Config.areas and Config.areas.GraphArea, "erro lendo Config")

g  = CurrentGraphic
ga = Config.areas.GraphArea

ga.tag = 1 -- ga  a primeira rea grfica. 

serlist  = {}
errlist  = {}
gridlist = {}

--
-- Altera estilo de desenho padro do grafico
--
CfgSetGraphStyle(g)

--
-- Cria margens para o grfico
--
CfgBuildMarginGuidelines(g)

-- 
-- Cria e configura ttulo e subttulo do grafico
--
CfgBuildTitleAreas(g, Config.graphTitle, Config.graphSubtitle)


--
--  Cria demais guidelines
--

-- Linhas verticais: limite eixo esq. / grafico
--                   limite esq. legenda
--                   limite dir. eixo formacoes
--                   limite litologias / esq. eixo formacoes
--                   limite grafico / litologias 
glvRightLegendLeft = SgLimitedGuideline:new(g, glvRightMargin,  -15, -40, 100, 250)
glvLeftLegendRight = SgLimitedGuideline:new(g, glvLeftMargin,    15,  45, 100, 250)
glvLegendLeftAxe   = SgFixedGuideline:new(g, glvLeftLegendRight, 2)

glvLeftAxeGraph    = SgLimitedGuideline:new(g, glvLeftLegendRight, 5,  15, 100, 250)
glvGraphLito     = SgFixedGuideline:new(g, glvRightLegendLeft, -2)

-- Linhas horizontais:  limite barra idades / grafico superior
--                      limite grfico inferior / eixo inferior
glhTopGraph = glhSubtitleBottom


--glhBottomLegendTop   = SgLegendGuideline:new(g, glhBottomMargin, 10, 20, 1, 3)
glhBottomLegendGraph = SgFixedGuideline:new(g, glhBottomMargin, 2)

glhBottomGraph  = SgLimitedGuideline:new(g, glhBottomLegendGraph, 10, 25, 100, 200)

glhSideLegendTop    = glhTopGraph
if ga.isrose then
  glhSideLegendBottom = SgLegendGuideline:new(g, glhSideLegendTop, -100, -120, 1, 10)
  glhTopRingGraph  = glhSideLegendBottom
else
  glhSideLegendBottom = SgLegendGuideline:new(g, glhSideLegendTop, -35, -60, 1, 10)
  glhTopRingGraph  = SgLimitedGuideline:new(g, glhBottomLegendGraph, 50, 50, 8, 8)
--  glhTopRingGraph  = glhSideLegendBottom
end

--g:showGuidelines(true)

--
-- Cria e configura a torta
--

local axe_type = 1
local series = ga[CfgGraphAreaFields.series[axe_type+1]]
if series then
  for i = 1, getn(series) do
    local serie1
    local v = series[i]
    local ds, e1, e2  = CfgLoadSeries(v, SeriesList[v].errorbar, SeriesList[v].user)
    serie1 = CfgBuildSeries(ds, v)
    CfgSetObjectTag(serie1, ga.tag, axe_type)
    if serlist then
      tinsert(serlist, serie1)
    end
  end
end

--
-- Grafico
--

local name = CfgBuildName('plotarea_')
graphArea = SgPieArea:new(g, name, glvLeftAxeGraph, glvGraphLito, glhBottomGraph, glhTopGraph)
graphArea:setUserTag(ga.tag * 1000)
graphArea:setNameExt(ga.title)
CfgSetPlotAreaStyle(graphArea)
if ga.isrose then
  roseGrid = SgRoseGrid:new("RoseGrid", graphArea)
  roseGrid:setLevel(-1)
  graphArea:addFreeObject(roseGrid, true, true)
  graphArea:setRadius(0.45, 0.2)
end
setglobal(name, graphArea)

for i = 1, getn(serlist) do
  graphArea:addSeries(serlist[i],true)
end


-- Legenda vertical de curvas (a direita)

rightLegendArea = SgPieLegendArea:new(g, "rightLegendArea", glvRightLegendLeft, glvRightMargin, 
                                  glhSideLegendBottom, glhSideLegendTop, VERTICAL, 1,  serlist[1], true,"%s")
rightLegendArea:style():pen():setLineStyle(LS_CONTINUOUS)
if Language == 'Portuguese' then
	rightLegendArea:setNameExt('Legenda')
else
	if Language == 'English' then
		rightLegendArea:setNameExt('Legend')
	else
		rightLegendArea:setNameExt('Leyenda') 
	end
end
rightLegendArea:setUserTag(2*1000+2) -- 2 = posicionamento a direita
rightLegendArea:setItemLimit(25)
glhSideLegendBottom:addArea(rightLegendArea)

function rightLegendArea:visibilityChanged(visible)
  if not visible then
   glvRightLegendLeft:setPos(0, 0, 100, 250)
   glvGraphLito:setOffset(0)
  else
   glvRightLegendLeft:setPos(-15, -30, 100, 250)
   glvGraphLito:setOffset(-2)
  end
end

-- Legenda vertical de curvas (a esquerda)

leftLegendArea = SgPieLegendArea:new(g, "leftLegendArea", glvLeftMargin, glvLeftLegendRight, 
                                  glhSideLegendBottom, glhSideLegendTop, VERTICAL, 1, serlist[1], true,"%s")
leftLegendArea:style():pen():setLineStyle(LS_CONTINUOUS)
if Language == 'Portuguese' then
	leftLegendArea:setNameExt('Legenda')
else
	if Language == 'English' then
		leftLegendArea:setNameExt('Legend')
	else
		leftLegendArea:setNameExt('Leyenda') 
	end
end
leftLegendArea:setUserTag(2*1000+1) -- 1 = posicionamento a esquerda
leftLegendArea:setItemLimit(25)
leftLegendArea:changeStyle(rightLegendArea:style())
glhSideLegendBottom:addArea(leftLegendArea)

function leftLegendArea:visibilityChanged(visible)
  if not visible then
   glvLeftLegendRight:setPos(0, 0, 100, 250)
   glvLegendLeftAxe:setOffset(0)
  else
   glvLeftLegendRight:setPos(15, 30, 100, 250)
   glvLegendLeftAxe:setOffset(2)
  end
end

if ga.isrose == nil then
  ringRightLegendArea = SgRingLegendArea:new(g, "ringRightLegendArea", glvRightLegendLeft, glvRightMargin, 
                                        glhBottomGraph, glhTopRingGraph, graphArea, true)

  ringRightLegendArea:ringStyle():font():setColor(blue)
  ringRightLegendArea:altRingStyle():brush():setFgColor(SgColor:new(220,220, 220))
  ringRightLegendArea:altRingStyle():font():setColor(blue)

  ringLeftLegendArea = SgRingLegendArea:new(g, "ringLeftLegendArea", glvLeftMargin, glvLeftLegendRight, 
                                        glhBottomGraph, glhTopRingGraph, graphArea, true)

  ringLeftLegendArea:ringStyle():font():setColor(blue)
  ringLeftLegendArea:altRingStyle():brush():setFgColor(SgColor:new(220,220, 220))
  ringLeftLegendArea:altRingStyle():font():setColor(blue)
end
-- Mantm visivel apenas legenda a direita
leftLegendArea:setVisible(nil)

-- Seleciona elementos configuraveis do template
ConfigElements = {}
ConfigElements.areas   = {graphArea, rightLegendArea}
ConfigElements.axes    = { }
ConfigElements.series  = serlist
ConfigElements.errors  = errlist
ConfigElements.grids   = gridlist
ConfigElements.legends = {rightLegendArea, leftLegendArea}
