-- 
-- Template para criacao de um grafico XY simples.
--
-- Pode ainda habilitar ou no legendas a esquerda ou abaixo do grafico.
-- A esquerda podemos contar com legenda de curvas
--
-- Ttulo e sub-ttulo do grfico podem ser escondidos de acordo com a 
-- necessidade.
--
-- Dados Recebidos:
--
-- Config.graphTitle    = Titulo do grafico
-- Config.graphSubtitle = Subtitulo do grafico
-- Config.templateName  = Nome do template selecionado
-- Config.templateIndex = Indice em TemplatesList contendo a descrica do 
--                        template
--
-- Config.areas = Tabela contendo dados relacionados com as areas de
--                desenho do template.  Deve possuir tantas entradas 
--                quanto o numero de PlotAreas do grfico, neste caso
--                especfico, apenas uma.  O nome de cada uma destas 
--                entradas deve ser correspondente ao nome cadastrado
--                no arquivo de configurao dos templates, neste caso, 
--                GraphArea
--
-- Config.areas.GraphArea = Conjunto de dados relacionados a rea de 
--                          desenho. Campos: 
--     title     = Nome extendido da rea
--     xaxeIndex = Indice correspondente ao eixo X na tabela AxeTypeList
--     xaxeTitle = Titulo do eixo X
--     xaxeDir   = Direcao do eixo X (HORIZONTAL ou VERTICAL)
--
--     y1axeIndex  = Indice correspondente ao eixo Y na tabela AxeTypeList.
--     y1axeTitle  = Titulo do eixo Y 
--     y1axeSeries = Tabela contendo os indices em SeriesList das curvas
--                   adicionadas a este eixo. 
--     
-- Para que o esquema padro de identificao de objetos funcione corretamente,
--  necessrio que reas e eixos sejam criados na mesma ordem em que esto
-- definidos no template bsico
--

assert(CurrentGraphic)
assert(Config and Config.areas and Config.areas.GraphArea, "erro lendo Config")

g  = CurrentGraphic
ga = Config.areas.GraphArea

ga.tag = 1 -- ga  a primeira rea grfica. 

serlist  = {}
errlist  = {}
gridlist = {}

--
-- Altera estilo de desenho padro do grafico
--
CfgSetGraphStyle(g)

--
-- Cria margens para o grfico
--
CfgBuildMarginGuidelines(g)

-- 
-- Cria e configura ttulo e subttulo do grafico
--
CfgBuildTitleAreas(g, Config.graphTitle, Config.graphSubtitle)


--
--  Cria demais guidelines
--

-- Linhas verticais: limite eixo esq. / grafico
--                   limite esq. legenda
--                   limite dir. eixo formacoes
--                   limite litologias / esq. eixo formacoes
--                   limite grafico / litologias 
glvRightLegendLeft = SgLimitedGuideline:new(g, glvRightMargin,  -15, -30, 100, 250)
glvLeftLegendRight = SgLimitedGuideline:new(g, glvLeftMargin,    15,  30, 100, 250)
glvLegendLeftAxe   = SgFixedGuideline:new(g, glvLeftLegendRight, 2)

glvLeftAxeGraph    = SgLimitedGuideline:new(g, glvLeftLegendRight, 15,  25, 100, 250)
glvGraphLito     = SgFixedGuideline:new(g, glvRightLegendLeft, -2)

-- Linhas horizontais:  limite barra idades / grafico superior
--                      limite grfico inferior / eixo inferior
  glhTopGraph = glhSubtitleBottom


glhBottomLegendTop   = SgLegendGuideline:new(g, glhBottomMargin, 6, 18, 1, 3)
glhBottomLegendGraph = SgFixedGuideline:new(g, glhBottomLegendTop, 2)

glhBottomGraph  = SgLimitedGuideline:new(g, glhBottomLegendGraph, 10, 25, 100, 200)

glhSideLegendTop    = glhTopGraph
glhSideLegendBottom = SgLegendGuideline:new(g, glhSideLegendTop, -6, -60, 1, 10) 


--g:showGuidelines(true)


--
-- Cria e configura eixos X e Y
--
xaxe = CfgBuildAxe(0, ga, 'GraphArea', serlist, errlist)
yaxe = CfgBuildAxe(1, ga, 'GraphArea', serlist, errlist)

xaxe:setAxeBorderSize(3.0)
xaxe:setShowMinor(true)
xaxe:setTextNoWrap(nil)

yaxe:setAxeBorderSize(3.0)
yaxe:setShowMinor(true)
yaxe:setTextNoWrap(nil)


--
-- Grafico
--
graphArea = CfgBuildPlotArea(ga, glvLeftAxeGraph, glvGraphLito, 
                             glhBottomGraph, glhTopGraph, 
                             xaxe, yaxe, gridlist)

-- 
-- Representao (escala) dos eixos X e Y
--
if ga.xaxeDir == HORIZONTAL then
  leftAxe      = yaxe
  bottomAxe    = xaxe
else
  bottomAxe    = yaxe
  leftAxe      = xaxe
end
  

leftAxeArea = SgAxeArea:new(g, "leftAxeArea", glvLegendLeftAxe, glvLeftAxeGraph, 
                            glhBottomGraph, glhTopGraph, leftAxe , true)
leftAxeArea:setShowTitles(true)
leftAxeArea:titleStyle():font():setStyle(TS_BOLD)

bottomAxeArea = SgAxeArea:new(g, "bottomAxeArea", glvLeftAxeGraph, glvGraphLito, 
                              glhBottomLegendGraph, glhBottomGraph, bottomAxe, true)
bottomAxeArea:setShowTitles(true)
bottomAxeArea:titleStyle():font():setStyle(TS_BOLD)

-- Barras de erro
CfgAddErrorBars(graphArea, errlist, yaxe)

                    
-- Legenda vertical de curvas (a direita)

rightLegendArea = SgLegendArea:new(g, "rightLegendArea", glvRightLegendLeft, glvRightMargin, 
                                  glhSideLegendBottom, glhSideLegendTop, HORIZONTAL, 1, yaxe)
rightLegendArea:style():pen():setLineStyle(LS_CONTINUOUS)
if Language == 'Portuguese' then
	rightLegendArea:setNameExt('Legenda')
else
	if Language == 'English' then
		rightLegendArea:setNameExt('Legend')
	else
		rightLegendArea:setNameExt('Leyenda') 
	end
end
rightLegendArea:setUserTag(2*1000+2) -- 2 = posicionamento a direita
rightLegendArea:setItemLimit(1)
glhSideLegendBottom:addArea(rightLegendArea)

function rightLegendArea:visibilityChanged(visible)
  if not visible then
   glvRightLegendLeft:setPos(0, 0, 100, 250)
   glvGraphLito:setOffset(0)
  else
   glvRightLegendLeft:setPos(-15, -30, 100, 250)
   glvGraphLito:setOffset(-2)
  end
end

-- Legenda vertical de curvas (a esquerda)

leftLegendArea = SgLegendArea:new(g, "leftLegendArea", glvLeftMargin, glvLeftLegendRight, 
                                  glhSideLegendBottom, glhSideLegendTop, HORIZONTAL, 1, yaxe)
leftLegendArea:style():pen():setLineStyle(LS_CONTINUOUS)
if Language == 'Portuguese' then
	leftLegendArea:setNameExt('Legenda')
else
	if Language == 'English' then
		leftLegendArea:setNameExt('Legend')
	else
		leftLegendArea:setNameExt('Leyenda') 
	end
end
leftLegendArea:setUserTag(2*1000+1) -- 1 = posicionamento a esquerda
leftLegendArea:setItemLimit(1)
leftLegendArea:changeStyle(rightLegendArea:style())
glhSideLegendBottom:addArea(leftLegendArea)

function leftLegendArea:visibilityChanged(visible)
  if not visible then
   glvLeftLegendRight:setPos(0, 0, 100, 250)
   glvLegendLeftAxe:setOffset(0)
  else
   glvLeftLegendRight:setPos(15, 30, 100, 250)
   glvLegendLeftAxe:setOffset(2)
  end
end

-- Legenda horizontal de curvas (abaixo)
bottomLegendArea = SgLegendArea:new(g, "bottomLegendArea", glvLeftAxeGraph, glvGraphLito,
                                    glhBottomMargin, glhBottomLegendTop, HORIZONTAL, 1, yaxe)
bottomLegendArea:style():pen():setLineStyle(LS_CONTINUOUS)
if Language == 'Portuguese' then
	bottomLegendArea:setNameExt('Legenda')
else
	if Language == 'English' then
		bottomLegendArea:setNameExt('Legend')
	else
		bottomLegendArea:setNameExt('Leyenda') 
	end
end
bottomLegendArea:setUserTag(2*1000+4) -- 4 = posicionamento em baixo
bottomLegendArea:setItemLimit(5)
bottomLegendArea:changeStyle(rightLegendArea:style())
glhBottomLegendTop:addArea(bottomLegendArea)

function bottomLegendArea:visibilityChanged(visible)
  if not visible then
   glhBottomLegendTop:setPos(0, 0, 1, 3)
   glhBottomLegendGraph:setOffset(0)
  else
   glhBottomLegendTop:setPos(6, 18, 1, 3)
   glhBottomLegendGraph:setOffset(2)
  end
end

-- Mantm visivel apenas legenda a direita
leftLegendArea:setVisible(nil)
bottomLegendArea:setVisible(nil)
rightLegendArea:setVisible(nil)

-- Seleciona elementos configuraveis do template
ConfigElements = {}
ConfigElements.areas   = {graphArea, rightLegendArea}
ConfigElements.axes    = {xaxe, yaxe}
ConfigElements.series  = serlist
ConfigElements.errors  = errlist
ConfigElements.grids   = gridlist
ConfigElements.legends = {rightLegendArea, leftLegendArea, bottomLegendArea}
